# Generated by Django 5.0.6 on 2024-05-25 14:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tests', '0003_testmodel_email_testmodel_personality_type_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='testmodel',
            name='likes_to_party',
            field=models.BooleanField(default=True),
        ),
        migrations.AlterField(
            model_name='testmodel',
            name='personality_type',
            field=models.CharField(choices=[('int', 'Introvert'), ('ext', 'Extrovert')], default='int', max_length=3),
        ),
    ]
