# Generated by Django 4.0.5 on 2023-08-03 17:38

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('tests', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='bigtestmodel',
            name='foreign_key',
            field=models.ForeignKey(default=271, on_delete=django.db.models.deletion.CASCADE, to='tests.testmodel'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='testmodel',
            name='birth_date',
            field=models.DateField(default=django.utils.timezone.localdate),
        ),
    ]
