# Generated by Django 5.0.6 on 2024-05-25 16:07

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tests', '0004_testmodel_likes_to_party_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='testmodel',
            name='bed_time',
            field=models.TimeField(default=django.utils.timezone.now),
        ),
    ]
