# Generated by Django 5.0.6 on 2024-08-09 21:38

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tests', '0006_uuidtestmodel_alter_testmodel_bed_time'),
    ]

    operations = [
        migrations.AddField(
            model_name='testmodel',
            name='best_friend',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='tests.testmodel'),
        ),
    ]
